@@ -210,6 +210,8 @@ class ForecastDataDaily:
         self._precip_probability = data["precip_probability"]
         self._precip_icon = data["precip_icon"]
         self._precip_type = data["precip_type"]
+        self._current_condition = data["current_condition"]
+        self._current_icon = data["current_icon"]
 
     @property
     def timestamp(self) -> dt:
@@ -271,6 +273,16 @@ class ForecastDataDaily:
         """Precipitation Icon."""
         return self._precip_type
 
+    @property
+    def current_condition(self) -> str:
+        """Return Current condition text."""
+        return self._current_condition
+
+    @property
+    def current_icon(self) -> str:
+        """Current Condition Icon."""
+        return self._current_icon
+
 class ForecastDataHourly:
     """A representation of Hour Based Forecast Weather Data."""
 
@@ -294,6 +306,8 @@ class ForecastDataHourly:
         self._wind_direction_icon = data["wind_direction_icon"]
         self._uv = data["uv"]
         self._feels_like = data["feels_like"]
+        self._current_condition = data["current_condition"]
+        self._current_icon = data["current_icon"]
 
     @property
     def timestamp(self) -> dt:
@@ -389,3 +403,13 @@ class ForecastDataHourly:
     def feels_like(self) -> float:
         """Return Feels Like Temperature."""
         return self._feels_like
+
+    @property
+    def current_condition(self) -> str:
+        """Return Current condition text."""
+        return self._current_condition
+
+    @property
+    def current_icon(self) -> str:
+        """Current Condition Icon."""
+        return self._current_icon
